@@ -1,9 +1,11 @@
+# mypy: allow-untyped-defs
+from __future__ import annotations
+
 import os
 import subprocess
 import sys
 import time
 from types import ModuleType
-from typing import List
 
 from _pytest.config import ExitCode
 from _pytest.config import PytestPluginManager
@@ -226,7 +228,7 @@ class TestInlineRunModulesCleanup:
 
     def spy_factory(self):
         class SysModulesSnapshotSpy:
-            instances: List["SysModulesSnapshotSpy"] = []  # noqa: F821
+            instances: list[SysModulesSnapshotSpy] = []
 
             def __init__(self, preserve=None) -> None:
                 SysModulesSnapshotSpy.instances.append(self)
@@ -398,7 +400,7 @@ class TestSysPathsSnapshot:
         original_data = list(getattr(sys, path_type))
         original_other = getattr(sys, other_path_type)
         original_other_data = list(original_other)
-        new: List[object] = []
+        new: list[object] = []
         snapshot = SysPathsSnapshot()
         monkeypatch.setattr(sys, path_type, new)
         snapshot.restore()
@@ -724,7 +726,7 @@ def test_run_result_repr() -> None:
     # known exit code
     r = pytester_mod.RunResult(1, outlines, errlines, duration=0.5)
     assert repr(r) == (
-        f"<RunResult ret={str(pytest.ExitCode.TESTS_FAILED)} len(stdout.lines)=3"
+        f"<RunResult ret={pytest.ExitCode.TESTS_FAILED!s} len(stdout.lines)=3"
         " len(stderr.lines)=4 duration=0.50s>"
     )
 
